import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'getsettings_platform_interface.dart';

/// An implementation of [GetSettingsPlatform] that uses method channels.
class MethodChannelGetSettingsPlatform extends GetSettingsPlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('GetsettingsPlugin');
  final eventChannel = const EventChannel("GetSettingsChannel");
  @override
  void onListenSettings(onEvent, onError) {
    eventChannel.receiveBroadcastStream().listen(onEvent, onError: onError);
  }

  @override
  Future<String?> getPlatformVersion() async {
    final version =
        await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  Future<bool?> isRotationOn() async {
    return await methodChannel.invokeMethod<bool>('isRotationOn');
  }
}
